#!/usr/bin/env python
import commands
import os
import sys
from da.analysis.tools_transcom import *

# Aggregated olson ecosystem regions for CT Europe

aggregates=[\
("Forests/Wooded" , (1, 2, 3, 5, 8, 10,) ) ,\
("Grass/Shrubs" , (4, 6, 13) ) ,\
("Crops/Agriculture", (14,) ) ,\
("Tundra/Taiga" , (7,9,16) ) ,\
("Coastal/Wet" , (11,15,17) ) ,\
("Ice/Water/Deserts" , (12,18,19) ) \
]

agg_dict={}
for k,v in aggregates:
    agg_dict[k]=v

ext_econams=[a for a,b in aggregates]
ext_ecocomps=[b for a,b in aggregates]

eco19_to_ecosums = zeros((19, 6),float)
for i,k in enumerate(ext_ecocomps):
    indices = [x-1 for x in k]
    eco19_to_ecosums[:,i].put(indices,1.0)

##### END OF REGION DEFINITIONS

def StateToGrid(values,regionmap,reverse=False,avg=False):
    """ 
    This method converts parameters from a CarbonTracker StateVector object to a gridded map of linear multiplication values. These
    can subsequently be used in the transport model code to multiply/manipulate fluxes

    """
    import numpy as np
    nregions  = regionmap.max()

    # dictionary for region <-> map conversions

    regs={}
    for r in np.arange(1,nregions+1):
         sel=(regionmap.flat == r).nonzero()
         if len(sel[0])>0: regs[r]=sel

    regionselect=regs

    if reverse:

        """ project 1x1 degree map onto ecoregions """

        result=np.zeros(nregions,float)
        for k,v in regionselect.iteritems():
            if avg: 
                result[k-1]=values.ravel().take(v).mean()
            else : 
                result[k-1]=values.ravel().take(v).sum()
        return result

    else:

        """ project ecoregion properties onto 1x1 degree map """

        result=np.zeros((180,360,),float)
        for k,v in regionselect.iteritems():
            result.put(v,values[k-1])

        return result

def globarea(im=360,jm=180,silent=True):
    """ Function calculates the surface area according to TM5 definitions"""
    import numpy as np

    radius      = 6.371e6  # the earth radius in meters
    deg2rad     = np.pi/180.
    g           = 9.80665 

    dxx         = 360.0/im*deg2rad 
    dyy         = 180.0/jm*deg2rad 
    lat         = np.arange(-90*deg2rad,90*deg2rad,dyy)
    dxy         = dxx*(np.sin(lat+dyy)-np.sin(lat))*radius**2
    area        = np.resize(np.repeat(dxy,im,axis=0) ,[jm,im])
    if not silent:
        print 'total area of field = ',np.sum(area.flat)
        print 'total earth area    = ',4*np.pi*radius**2
    return area

