#!/usr/bin/env python
# model.py

"""
.. module:: observationoperator
.. moduleauthor:: Wouter Peters 

Revision History:
File created on 30 Aug 2010.

"""

import os
import sys
import logging
import datetime

identifier      = 'GeneralObservationOperator'
version         = '0.0'

################### Begin Class ObservationOperator ###################
class ObservationOperator(object):
    """
    Testing
    =======
    This is a class that defines an ObervationOperator. This object is used to control the sampling of
    a statevector in the ensemble Kalman filter framework. The methods of this class specify which (external) code
    is called to perform the sampling, and which files should be read for input and are written for output.

    The baseclasses consist mainly of empty methods that require an application specific application

    """

    def __init__(self, RcFileName,DaCycle = None):
        """ The instance of an ObservationOperator is application dependent """
        self.Identifier = self.getid()
        self.Version    = self.getversion()
        self.RestartFileList = []
        self.outputdir = None # Needed for opening the samples.nc files created 

        dummy               = self.LoadRc(RcFilename)   # load the specified rc-file
        dummy               = self.ValidateRc()         # validate the contents

        msg                 = 'Observation Operator object initialized: %s'%self.Identifier ; logging.info(msg)

        # The following code allows the object to be initialized with a DaCycle object already present. Otherwise, it can
        # be added at a later moment.

        if DaCycle != None:
            self.DaCycle = DaCycle
        else:
            self.DaCycle = {}

    def getid(self):
        return identifier

    def getversion(self):
        return version
    
    def GetInitialData(self):
        """ This method places all initial data needed by an ObservationOperator in the proper folder for the model """

        return None

    def __str__(self):
        return "This is a %s object, version %s"%(self.Identifier,self.Version)

    def Initialize(self):
        """ Perform all steps necessary to start the observation operator through a simple Run() call """

    def ValidateInput(self):
        """ Make sure that data needed for the ObservationOperator (such as observation input lists, or parameter files)
            are present.
        """
    def SaveData(self):
        """ Write the data that is needed for a restart or recovery of the Observation Operator to the save directory """



################### End Class ObservationOperator ###################



if __name__ == "__main__":
    pass
