#!/usr/bin/env python
# optimizer.py

"""
Author : peters 

Revision History:
File created on 28 Jul 2010.

"""

import os
import sys
sys.path.append(os.getcwd())
import logging
import datetime
from da.baseclasses.optimizer import Optimizer


identifier = 'Ensemble Square Root Filter'
version = '0.0'

################### Begin Class CtOptimizer ###################

class CtOptimizer(Optimizer):
    """
        This creates an instance of a CarbonTracker optimization object. The base class it derives from is the optimizer object.
        Additionally, this CtOptimizer implements a special localization option following the CT2007 method.

        All other methods are inherited from the base class Optimizer.
    """
    def getid(self):
        return identifier

    def getversion(self):
        return version


    def SetLocalization(self,type='None'):
        """ determine which localization to use """

        if type == 'CT2007':
            self.localization = True
            self.localizetype = 'CT2007'
        else:
            self.localization = False
            self.localizetype = 'None'
    
        msg       = "Current localization option is set to %s"%self.localizetype  ; logging.info(msg)

    def Localize(self,n):
        """ localize the Kalman Gain matrix """
        import numpy as np
    
        if not self.localization: return 
        if self.localizetype == 'CT2007':

            tvalue=1.97591
            if np.sqrt(self.R[n,n]) >= 1.5:
                for r in range(self.nlag*self.nparams):
                    corr=np.corrcoef(self.HX_prime[n,:],self.X_prime[r,:].squeeze())[0,1]
                    prob=corr/np.sqrt((1.0-corr**2)/(self.nmembers-2))
                    if abs(prob) < tvalue:
                        self.KG[r,n]=0.0


################### End Class CtOptimizer ###################





if __name__ == "__main__":

    import os
    import sys
    from da.tools.initexit import StartLogger 
    from da.tools.pipeline import JobStart 

    sys.path.append(os.getcwd())

    opts = ['-v']
    args = {'rc':'da.rc','logfile':'da_initexit.log','jobrcfilename':'test.rc'}

    StartLogger()

    DaCycle = JobStart(opts,args)
    DaCycle.Initialize()

    opt = CtOptimizer()

    nobs      = 100
    dims      = ( int(DaCycle['time.nlag']),
                  int(DaCycle['da.optimizer.nmembers']),
                  int(DaCycle.DaSystem['nparameters']),
                  nobs,  )

    opt.Initialize(dims)
    opt.SetLocalization(type='CT2007')
