#!/usr/bin/env python
# ct_tools.py

"""
Author : peters 

Revision History:
File created on 12 Feb 2009.

"""
import os
import sys
import logging
import datetime

identifier = 'CarbonTracker CO2'

def StateToGrid(values,regionmap,reverse=False,avg=False):
    """ 
    This method converts parameters from a CarbonTracker StateVector object to a gridded map of linear multiplication values. These
    can subsequently be used in the transport model code to multiply/manipulate fluxes

    """
    import numpy as np
    nregions  = regionmap.max()

    # dictionary for region <-> map conversions

    regs={}
    for r in np.arange(1,nregions+1):
         sel=(regionmap.flat == r).nonzero()
         if len(sel[0])>0: regs[r]=sel

    regionselect=regs

    if reverse:

        """ project 1x1 degree map onto ecoregions """

        result=np.zeros(nregions,float)
        for k,v in regionselect.iteritems():
            if avg: 
                result[k-1]=values.ravel().take(v).mean()
            else : 
                result[k-1]=values.ravel().take(v).sum()
        return result

    else:

        """ project ecoregion properties onto 1x1 degree map """

        result=np.zeros((180,360,),float)
        for k,v in regionselect.iteritems():
            result.put(v,values[k-1])

        return result

if __name__ == "__main__":

    sys.path.append('../../')

    import os
    import sys
    from da.tools.general import StartLogger 
    from da.tools.initexit import CycleControl 
    import numpy as np
    import da.tools.rc as rc 
    from pylab import *

    opts = ['-v']
    args = {'rc':'da.rc','logfile':'da_initexit.log','jobrcfilename':'test.rc'}

    StartLogger()
    DaCycle = CycleControl(opts,args)

    DaCycle.Initialize()
    print DaCycle

    a=arange(240)+100

    b = StateToGrid(DaCycle.DaSystem,a)

    figure()
    imshow(b)
    colorbar()
    print b.max()

    c = StateToGrid(DaCycle.DaSystem,b,reverse=True,avg=True)

    figure()
    print c.max()

    plot(a,label='original') 
    plot(c,label='reconstructed') 
    legend(loc=0)


    show()

    



